import { Emitter } from "./emitter";
import { Node, Dict as NodeDict, List as NodeList, Scalar as NodeScalar } from "./node";
import { Parser } from "./parser";
export declare type Dict = {
    [key: string]: ConfigValue;
};
export declare type List = Array<ConfigValue>;
export declare type ConfigValue = string | boolean | number | Dict | List;
export declare class Config {
    protected parser: Parser;
    protected emitter: Emitter;
    protected content: string;
    config: Dict;
    fileName: string;
    /**
     *
     * @param {string} fileName
     * @param {Object} predefinedValues [optional]
     */
    constructor(fileName: string, preDefines?: Object);
    protected existsFile(path: string): boolean;
    protected createFile(path: string): void;
    protected loadFile(path: string): void;
    protected isNumber(value: string): boolean;
    protected isFloat(value: string): boolean;
    protected parseNode(node: Node<NodeDict | NodeList | NodeScalar>): ConfigValue;
    protected parse(): void;
    /**
     * Get a config value with unknown type, slower than GetOfType
     * @param {string} key
     * @returns {ConfigValue}
     */
    get(key: string): ConfigValue;
    /**
     * Set a config value
     * @param {string} key
     * @param {ConfigValue} value
     */
    set(key: string, value: ConfigValue): void;
    /**
     * Save the current changes to the opened file
     * @param {boolean} useCommas [default: true]
     * @param {boolean} useApostrophe [default: true]
     *
     * @returns {Promise<void>}
     */
    save(useCommas?: boolean, useApostrophe?: boolean): Promise<void>;
    /**
     * Get a config value with known type, faster than normal Get
     * @param {string} key
     * @param {ValueType} type
     * @returns {ReturnValueType}
     */
    getOfType<ReturnValueType>(key: string): ReturnValueType;
    /**
     * Serialize config
     * @param {boolean} useCommas [default: true]
     * @param {boolean} useApostrophe [default: true]
     * @returns {string}
     */
    serialize(useCommas?: boolean, useApostrophe?: boolean): string;
}
