import { Dict, List, Node, Scalar } from "./node";
export declare enum TokenType {
    ArrayStart = 0,
    ArrayEnd = 1,
    DictStart = 2,
    DictEnd = 3,
    Key = 4,
    Scalar = 5
}
export declare enum ErrorType {
    KeyExpected = 0,
    InvalidToken = 1,
    UnexpectedEOF = 2
}
declare class Token {
    type: TokenType;
    value: string;
    pos: number;
    line: number;
    col: number;
    constructor(_type: TokenType, _value?: string, _pos?: number, _line?: number, _col?: number);
}
export declare class Parser {
    tokens: Token[];
    buffer: string;
    readPos: number;
    line: number;
    column: number;
    tokIdx: number;
    filePath: string;
    constructor(content: string, filePath?: string);
    parse(): Node<Dict>;
    protected unread(): number;
    protected peek(offset?: number): string;
    protected get(): string;
    protected skip(n?: number): void;
    protected skipNextToken(): void;
    protected tokenize(): void;
    protected createParseError(type: ErrorType, token: Token | number, col?: number): string;
    protected parseToken(): Node<Dict | List | Scalar>;
}
export {};
